@@ -1,11 +1,14 @@
 from PythUnity import Variables
+from PythUnity import Functions
 import copy
 import pygame
+import types
 class Object:
   def __init__(self, rect, image, onClick = None, onDrag = None, onClickOff = None, enableDragOff = False):
     self.destroyed = False
     self.parent = None
     self.children = []
+    self.variables = {}
     self.image = None
     self.text = None
     self.color = None
@@ -13,7 +16,7 @@ class Object:
     if(type(image) is tuple):
       self.color = image
     elif(type(image) is String):
-      self.text = image
+      self.text = copy.deepcopy(image)
     else:
       self.image = image 
       ratio = image.get_size()
@@ -28,6 +31,12 @@ class Object:
       self.button = Button(onClick, onDrag, onClickOff, enableDragOff)
     else:
       self.button = None
+    Functions.AddObject(self)
+  #####
+  def __getitem__(self, i):
+    return self.children[i]
+  def __len__(self):
+    return len(self.children)
   #####
   def Decendants(self):
     Throw(self)
@@ -71,15 +80,15 @@ class Object:
   def Copy(self):
     Throw(self)
     CopyHelp(self)
-
     parChildren = self.GetParentChildren()
     copied = copy.deepcopy(self)
-    
-    copied.index = len(parChildren) - 1
+    copied.index = len(parChildren)
     parChildren.append(copied)
+    copied.parent = self.parent
     copied.Move(self.index + 1)
     CopyUnHelp(self)
     CopyUnHelp(copied)
+    CopyHelp2(copied)
     return copied
   def Destroy(self):
     Throw(self)
@@ -120,6 +129,15 @@ def CopyUnHelp(self):
     self.image = pygame.image.fromstring(self.image, self.rect.size, 'RGBA')
   for i in self.children:
     CopyUnHelp(i)
+def CopyHelp2(self):
+  for att in dir(self):
+    attObj = getattr(self, att)
+    if(att[0] != "_"):
+        attType = type(attObj)
+        if(attType is not types.MethodType and attType is not list and attType is not type(None) and attType is not Object):
+            attObj = copy.deepcopy(attObj)
+  for i in self.children:
+    CopyHelp2(i)
 def Throw(self):
   if(self.destroyed):
     raise Exception("Object was destroyed")
\ No newline at end of file
